//*----------------------------------------------------------------------------
//*         ATMEL Microcontroller Software Support  -  ROUSSET  -
//*----------------------------------------------------------------------------
//* The software is delivered "AS IS" without warranty or condition of any
//* kind, either express, implied or statutory. This includes without
//* limitation any warranty or condition with respect to merchantability or
//* fitness for any particular purpose, or against the infringements of
//* intellectual property rights of others.
//*----------------------------------------------------------------------------
//* File Name           : main.c
//* Object              : main application written in C
//* Creation            : JPP   16/Jun/2004
//*----------------------------------------------------------------------------

// Include Standard files
#include "Board.h"
#include "Cstartup_SAM7.h"

#define BR    19200                        /* Baud Rate */

#define BRD  (MCK/16/BR)                    /* Baud Rate Divisor */


AT91S_USART * pUSART = AT91C_BASE_US1;      /* Global Pointer to USART0 */

void uart1_init (void) {                   /* Initialize Serial Interface */

	/* mt: n.b: uart0 clock must be enabled to use it */

	*AT91C_PIOA_PDR = AT91C_PA21_RXD1 |        /* Enable RxD1 Pin */
		AT91C_PA22_TXD1;         /* Enalbe TxD1 Pin */

	pUSART->US_CR = AT91C_US_RSTRX |          /* Reset Receiver      */
		AT91C_US_RSTTX |          /* Reset Transmitter   */
		AT91C_US_RXDIS |          /* Receiver Disable    */
		AT91C_US_TXDIS;           /* Transmitter Disable */

	pUSART->US_MR = AT91C_US_USMODE_NORMAL |  /* Normal Mode */
		AT91C_US_CLKS_CLOCK    |  /* Clock = MCK */
		AT91C_US_CHRL_8_BITS   |  /* 8-bit Data  */
		AT91C_US_PAR_NONE      |  /* No Parity   */
		AT91C_US_NBSTOP_1_BIT;    /* 1 Stop Bit  */

	pUSART->US_BRGR = BRD;                    /* Baud Rate Divisor */

	pUSART->US_CR = AT91C_US_RXEN  |          /* Receiver Enable     */
		AT91C_US_TXEN;            /* Transmitter Enable  */
}


int uart1_putc(int ch) 
{
	while (!(pUSART->US_CSR & AT91C_US_TXRDY));   /* Wait for Empty Tx Buffer */
	return (pUSART->US_THR = ch);                 /* Transmit Character */
}	

int uart1_putchar (int ch) {                      /* Write Character to Serial Port */

	if (ch == '\n')  {                            /* Check for LF */
		uart1_putc( '\r' );                         /* Output CR */
	}
	return uart1_putc( ch );                     /* Transmit Character */
}

int uart1_puts ( char* s )
{
	while ( *s ) uart1_putchar( *s++ );
	return 0;
}

int uart1_kbhit( void ) /* returns true if character in receive buffer */
{
	if ( pUSART->US_CSR & AT91C_US_RXRDY) {
		return 1;
	}
	else {
		return 0;
	}
}

int uart1_getc ( void )  /* Read Character from Serial Port */
{    

	while (!(pUSART->US_CSR & AT91C_US_RXRDY));   /* Wait for Full Rx Buffer */
	return (pUSART->US_RHR);                      /* Read Character */
}



//*--------------------------------------------------------------------------------------
//* Function Name       : wait
//* Object              : Software waiting loop
//* Input Parameters    : none. Waiting time is defined by the global variable LedSpeed.
//* Output Parameters   : none
//*--------------------------------------------------------------------------------------

//*--------------------------------------------------------------------------------------
//* Function Name       : Main
//* Object              : Software entry point
//* Input Parameters    : none.
//* Output Parameters   : none.
//*--------------------------------------------------------------------------------------
int main(void)
{
	volatile int i;
	int iRxData;
	unsigned long keystate;

	i = 0xDEAD;

	// call low-level init
	AT91F_LowLevelInit();

	// enable the clock of the PIO (mt:) and UART0
	AT91F_PMC_EnablePeriphClock ( AT91C_BASE_PMC, ( 1 << AT91C_ID_PIOA ) | ( 1 << AT91C_ID_US1 ) ) ;

	// then, we configure the PIO Lines corresponding to LED1 to LED4
	// to be outputs. No need to set these pins to be driven by the PIO because it is GPIO pins only.
	AT91F_PIO_CfgOutput( AT91C_BASE_PIOA, LED_MASK ) ;

	// Clear the LED's. On the EB55 we must apply a "1" to turn off LEDs
	AT91F_PIO_SetOutput( AT91C_BASE_PIOA, LED_MASK ) ;


	// mt: enable reset-key on demo-board ("say hello on key")
	AT91F_RSTSetMode( AT91C_BASE_RSTC , AT91C_RSTC_URSTEN );

	uart1_init();
//	uart1_puts("\n\nHello World! (WinARM) (2c/tango/814)\n");

//	rprintf("rprintf Test %i %i %i\n", 1, 2, 3);

	// Loop forever
	for (;;)
	{


		if(1== uart1_kbhit())
		{
			iRxData= uart1_getc();

			uart1_putc(iRxData);
		}


	} // End for
}
